@@ -1,5 +1,6 @@
 /*
  * cog.h
+ * Copyright (C) 2021 Igalia S.L.
  * Copyright (C) 2018 Eduardo Lima <elima@igalia.com>
  * Copyright (C) 2017-2018 Adrian Perez <aperez@igalia.com>
  *
@@ -15,13 +16,11 @@
 #include "cog-webkit-utils.h"
 #include "cog-request-handler.h"
 #include "cog-directory-files-handler.h"
+#include "cog-prefix-routes-handler.h"
 #include "cog-launcher.h"
 #include "cog-shell.h"
 #include "cog-utils.h"
-
-#if !COG_USE_WEBKITGTK
-# include "cog-platform.h"
-#endif /* !COG_USE_WEBKITGTK */
+#include "cog-platform.h"
 
 #undef COG_INSIDE_COG__
 
